from google.protobuf import timestamp_pb2 as _timestamp_pb2
import types_pb2 as _types_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import (
    ClassVar as _ClassVar,
    Iterable as _Iterable,
    Mapping as _Mapping,
    Optional as _Optional,
    Union as _Union,
)

DESCRIPTOR: _descriptor.FileDescriptor

class L1DataAvailabilityMode(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = []
    L1_DATA_AVAILABILITY_MODE_UNSPECIFIED: _ClassVar[L1DataAvailabilityMode]
    L1_DATA_AVAILABILITY_MODE_BLOB: _ClassVar[L1DataAvailabilityMode]
    L1_DATA_AVAILABILITY_MODE_CALLDATA: _ClassVar[L1DataAvailabilityMode]

class BlockStatus(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = []
    BLOCK_STATUS_UNSPECIFIED: _ClassVar[BlockStatus]
    BLOCK_STATUS_PENDING: _ClassVar[BlockStatus]
    BLOCK_STATUS_ACCEPTED_ON_L2: _ClassVar[BlockStatus]
    BLOCK_STATUS_ACCEPTED_ON_L1: _ClassVar[BlockStatus]
    BLOCK_STATUS_REJECTED: _ClassVar[BlockStatus]

class ExecutionStatus(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = []
    EXECUTION_STATUS_UNSPECIFIED: _ClassVar[ExecutionStatus]
    EXECUTION_STATUS_SUCCEEDED: _ClassVar[ExecutionStatus]
    EXECUTION_STATUS_REVERTED: _ClassVar[ExecutionStatus]

class PriceUnit(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = []
    PRICE_UNIT_UNSPECIFIED: _ClassVar[PriceUnit]
    PRICE_UNIT_WEI: _ClassVar[PriceUnit]
    PRICE_UNIT_FRI: _ClassVar[PriceUnit]

class DataAvailabilityMode(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = []
    DATA_AVAILABILITY_MODE_UNSPECIFIED: _ClassVar[DataAvailabilityMode]
    DATA_AVAILABILITY_MODE_L1: _ClassVar[DataAvailabilityMode]
    DATA_AVAILABILITY_MODE_L2: _ClassVar[DataAvailabilityMode]

L1_DATA_AVAILABILITY_MODE_UNSPECIFIED: L1DataAvailabilityMode
L1_DATA_AVAILABILITY_MODE_BLOB: L1DataAvailabilityMode
L1_DATA_AVAILABILITY_MODE_CALLDATA: L1DataAvailabilityMode
BLOCK_STATUS_UNSPECIFIED: BlockStatus
BLOCK_STATUS_PENDING: BlockStatus
BLOCK_STATUS_ACCEPTED_ON_L2: BlockStatus
BLOCK_STATUS_ACCEPTED_ON_L1: BlockStatus
BLOCK_STATUS_REJECTED: BlockStatus
EXECUTION_STATUS_UNSPECIFIED: ExecutionStatus
EXECUTION_STATUS_SUCCEEDED: ExecutionStatus
EXECUTION_STATUS_REVERTED: ExecutionStatus
PRICE_UNIT_UNSPECIFIED: PriceUnit
PRICE_UNIT_WEI: PriceUnit
PRICE_UNIT_FRI: PriceUnit
DATA_AVAILABILITY_MODE_UNSPECIFIED: DataAvailabilityMode
DATA_AVAILABILITY_MODE_L1: DataAvailabilityMode
DATA_AVAILABILITY_MODE_L2: DataAvailabilityMode

class Block(_message.Message):
    __slots__ = [
        "status",
        "header",
        "transactions",
        "state_update",
        "events",
        "l2_to_l1_messages",
        "empty",
    ]
    STATUS_FIELD_NUMBER: _ClassVar[int]
    HEADER_FIELD_NUMBER: _ClassVar[int]
    TRANSACTIONS_FIELD_NUMBER: _ClassVar[int]
    STATE_UPDATE_FIELD_NUMBER: _ClassVar[int]
    EVENTS_FIELD_NUMBER: _ClassVar[int]
    L2_TO_L1_MESSAGES_FIELD_NUMBER: _ClassVar[int]
    EMPTY_FIELD_NUMBER: _ClassVar[int]
    status: BlockStatus
    header: BlockHeader
    transactions: _containers.RepeatedCompositeFieldContainer[TransactionWithReceipt]
    state_update: StateUpdate
    events: _containers.RepeatedCompositeFieldContainer[EventWithTransaction]
    l2_to_l1_messages: _containers.RepeatedCompositeFieldContainer[
        L2ToL1MessageWithTransaction
    ]
    empty: bool
    def __init__(
        self,
        status: _Optional[_Union[BlockStatus, str]] = ...,
        header: _Optional[_Union[BlockHeader, _Mapping]] = ...,
        transactions: _Optional[
            _Iterable[_Union[TransactionWithReceipt, _Mapping]]
        ] = ...,
        state_update: _Optional[_Union[StateUpdate, _Mapping]] = ...,
        events: _Optional[_Iterable[_Union[EventWithTransaction, _Mapping]]] = ...,
        l2_to_l1_messages: _Optional[
            _Iterable[_Union[L2ToL1MessageWithTransaction, _Mapping]]
        ] = ...,
        empty: bool = ...,
    ) -> None: ...

class BlockHeader(_message.Message):
    __slots__ = [
        "block_hash",
        "parent_block_hash",
        "block_number",
        "sequencer_address",
        "new_root",
        "timestamp",
        "starknet_version",
        "l1_gas_price",
        "l1_data_gas_price",
        "l1_data_availability_mode",
    ]
    BLOCK_HASH_FIELD_NUMBER: _ClassVar[int]
    PARENT_BLOCK_HASH_FIELD_NUMBER: _ClassVar[int]
    BLOCK_NUMBER_FIELD_NUMBER: _ClassVar[int]
    SEQUENCER_ADDRESS_FIELD_NUMBER: _ClassVar[int]
    NEW_ROOT_FIELD_NUMBER: _ClassVar[int]
    TIMESTAMP_FIELD_NUMBER: _ClassVar[int]
    STARKNET_VERSION_FIELD_NUMBER: _ClassVar[int]
    L1_GAS_PRICE_FIELD_NUMBER: _ClassVar[int]
    L1_DATA_GAS_PRICE_FIELD_NUMBER: _ClassVar[int]
    L1_DATA_AVAILABILITY_MODE_FIELD_NUMBER: _ClassVar[int]
    block_hash: _types_pb2.FieldElement
    parent_block_hash: _types_pb2.FieldElement
    block_number: int
    sequencer_address: _types_pb2.FieldElement
    new_root: _types_pb2.FieldElement
    timestamp: _timestamp_pb2.Timestamp
    starknet_version: str
    l1_gas_price: ResourcePrice
    l1_data_gas_price: ResourcePrice
    l1_data_availability_mode: L1DataAvailabilityMode
    def __init__(
        self,
        block_hash: _Optional[_Union[_types_pb2.FieldElement, _Mapping]] = ...,
        parent_block_hash: _Optional[_Union[_types_pb2.FieldElement, _Mapping]] = ...,
        block_number: _Optional[int] = ...,
        sequencer_address: _Optional[_Union[_types_pb2.FieldElement, _Mapping]] = ...,
        new_root: _Optional[_Union[_types_pb2.FieldElement, _Mapping]] = ...,
        timestamp: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ...,
        starknet_version: _Optional[str] = ...,
        l1_gas_price: _Optional[_Union[ResourcePrice, _Mapping]] = ...,
        l1_data_gas_price: _Optional[_Union[ResourcePrice, _Mapping]] = ...,
        l1_data_availability_mode: _Optional[_Union[L1DataAvailabilityMode, str]] = ...,
    ) -> None: ...

class TransactionWithReceipt(_message.Message):
    __slots__ = ["transaction", "receipt"]
    TRANSACTION_FIELD_NUMBER: _ClassVar[int]
    RECEIPT_FIELD_NUMBER: _ClassVar[int]
    transaction: Transaction
    receipt: TransactionReceipt
    def __init__(
        self,
        transaction: _Optional[_Union[Transaction, _Mapping]] = ...,
        receipt: _Optional[_Union[TransactionReceipt, _Mapping]] = ...,
    ) -> None: ...

class Transaction(_message.Message):
    __slots__ = [
        "meta",
        "invoke_v0",
        "invoke_v1",
        "deploy",
        "declare",
        "l1_handler",
        "deploy_account",
        "deploy_account_v3",
        "invoke_v3",
        "declare_v3",
    ]
    META_FIELD_NUMBER: _ClassVar[int]
    INVOKE_V0_FIELD_NUMBER: _ClassVar[int]
    INVOKE_V1_FIELD_NUMBER: _ClassVar[int]
    DEPLOY_FIELD_NUMBER: _ClassVar[int]
    DECLARE_FIELD_NUMBER: _ClassVar[int]
    L1_HANDLER_FIELD_NUMBER: _ClassVar[int]
    DEPLOY_ACCOUNT_FIELD_NUMBER: _ClassVar[int]
    DEPLOY_ACCOUNT_V3_FIELD_NUMBER: _ClassVar[int]
    INVOKE_V3_FIELD_NUMBER: _ClassVar[int]
    DECLARE_V3_FIELD_NUMBER: _ClassVar[int]
    meta: TransactionMeta
    invoke_v0: InvokeTransactionV0
    invoke_v1: InvokeTransactionV1
    deploy: DeployTransaction
    declare: DeclareTransaction
    l1_handler: L1HandlerTransaction
    deploy_account: DeployAccountTransaction
    deploy_account_v3: DeployAccountTransactionV3
    invoke_v3: InvokeTransactionV3
    declare_v3: DeclareTransactionV3
    def __init__(
        self,
        meta: _Optional[_Union[TransactionMeta, _Mapping]] = ...,
        invoke_v0: _Optional[_Union[InvokeTransactionV0, _Mapping]] = ...,
        invoke_v1: _Optional[_Union[InvokeTransactionV1, _Mapping]] = ...,
        deploy: _Optional[_Union[DeployTransaction, _Mapping]] = ...,
        declare: _Optional[_Union[DeclareTransaction, _Mapping]] = ...,
        l1_handler: _Optional[_Union[L1HandlerTransaction, _Mapping]] = ...,
        deploy_account: _Optional[_Union[DeployAccountTransaction, _Mapping]] = ...,
        deploy_account_v3: _Optional[
            _Union[DeployAccountTransactionV3, _Mapping]
        ] = ...,
        invoke_v3: _Optional[_Union[InvokeTransactionV3, _Mapping]] = ...,
        declare_v3: _Optional[_Union[DeclareTransactionV3, _Mapping]] = ...,
    ) -> None: ...

class TransactionMeta(_message.Message):
    __slots__ = [
        "hash",
        "max_fee",
        "signature",
        "nonce",
        "version",
        "resource_bounds",
        "tip",
        "paymaster_data",
        "nonce_data_availability_mode",
        "fee_data_availability_mode",
        "transaction_index",
    ]
    HASH_FIELD_NUMBER: _ClassVar[int]
    MAX_FEE_FIELD_NUMBER: _ClassVar[int]
    SIGNATURE_FIELD_NUMBER: _ClassVar[int]
    NONCE_FIELD_NUMBER: _ClassVar[int]
    VERSION_FIELD_NUMBER: _ClassVar[int]
    RESOURCE_BOUNDS_FIELD_NUMBER: _ClassVar[int]
    TIP_FIELD_NUMBER: _ClassVar[int]
    PAYMASTER_DATA_FIELD_NUMBER: _ClassVar[int]
    NONCE_DATA_AVAILABILITY_MODE_FIELD_NUMBER: _ClassVar[int]
    FEE_DATA_AVAILABILITY_MODE_FIELD_NUMBER: _ClassVar[int]
    TRANSACTION_INDEX_FIELD_NUMBER: _ClassVar[int]
    hash: _types_pb2.FieldElement
    max_fee: _types_pb2.FieldElement
    signature: _containers.RepeatedCompositeFieldContainer[_types_pb2.FieldElement]
    nonce: _types_pb2.FieldElement
    version: int
    resource_bounds: ResourceBoundsMapping
    tip: int
    paymaster_data: _containers.RepeatedCompositeFieldContainer[_types_pb2.FieldElement]
    nonce_data_availability_mode: DataAvailabilityMode
    fee_data_availability_mode: DataAvailabilityMode
    transaction_index: int
    def __init__(
        self,
        hash: _Optional[_Union[_types_pb2.FieldElement, _Mapping]] = ...,
        max_fee: _Optional[_Union[_types_pb2.FieldElement, _Mapping]] = ...,
        signature: _Optional[
            _Iterable[_Union[_types_pb2.FieldElement, _Mapping]]
        ] = ...,
        nonce: _Optional[_Union[_types_pb2.FieldElement, _Mapping]] = ...,
        version: _Optional[int] = ...,
        resource_bounds: _Optional[_Union[ResourceBoundsMapping, _Mapping]] = ...,
        tip: _Optional[int] = ...,
        paymaster_data: _Optional[
            _Iterable[_Union[_types_pb2.FieldElement, _Mapping]]
        ] = ...,
        nonce_data_availability_mode: _Optional[
            _Union[DataAvailabilityMode, str]
        ] = ...,
        fee_data_availability_mode: _Optional[_Union[DataAvailabilityMode, str]] = ...,
        transaction_index: _Optional[int] = ...,
    ) -> None: ...

class InvokeTransactionV0(_message.Message):
    __slots__ = ["contract_address", "entry_point_selector", "calldata"]
    CONTRACT_ADDRESS_FIELD_NUMBER: _ClassVar[int]
    ENTRY_POINT_SELECTOR_FIELD_NUMBER: _ClassVar[int]
    CALLDATA_FIELD_NUMBER: _ClassVar[int]
    contract_address: _types_pb2.FieldElement
    entry_point_selector: _types_pb2.FieldElement
    calldata: _containers.RepeatedCompositeFieldContainer[_types_pb2.FieldElement]
    def __init__(
        self,
        contract_address: _Optional[_Union[_types_pb2.FieldElement, _Mapping]] = ...,
        entry_point_selector: _Optional[
            _Union[_types_pb2.FieldElement, _Mapping]
        ] = ...,
        calldata: _Optional[_Iterable[_Union[_types_pb2.FieldElement, _Mapping]]] = ...,
    ) -> None: ...

class InvokeTransactionV1(_message.Message):
    __slots__ = ["sender_address", "calldata"]
    SENDER_ADDRESS_FIELD_NUMBER: _ClassVar[int]
    CALLDATA_FIELD_NUMBER: _ClassVar[int]
    sender_address: _types_pb2.FieldElement
    calldata: _containers.RepeatedCompositeFieldContainer[_types_pb2.FieldElement]
    def __init__(
        self,
        sender_address: _Optional[_Union[_types_pb2.FieldElement, _Mapping]] = ...,
        calldata: _Optional[_Iterable[_Union[_types_pb2.FieldElement, _Mapping]]] = ...,
    ) -> None: ...

class InvokeTransactionV3(_message.Message):
    __slots__ = ["sender_address", "calldata", "account_deployment_data"]
    SENDER_ADDRESS_FIELD_NUMBER: _ClassVar[int]
    CALLDATA_FIELD_NUMBER: _ClassVar[int]
    ACCOUNT_DEPLOYMENT_DATA_FIELD_NUMBER: _ClassVar[int]
    sender_address: _types_pb2.FieldElement
    calldata: _containers.RepeatedCompositeFieldContainer[_types_pb2.FieldElement]
    account_deployment_data: _containers.RepeatedCompositeFieldContainer[
        _types_pb2.FieldElement
    ]
    def __init__(
        self,
        sender_address: _Optional[_Union[_types_pb2.FieldElement, _Mapping]] = ...,
        calldata: _Optional[_Iterable[_Union[_types_pb2.FieldElement, _Mapping]]] = ...,
        account_deployment_data: _Optional[
            _Iterable[_Union[_types_pb2.FieldElement, _Mapping]]
        ] = ...,
    ) -> None: ...

class DeployTransaction(_message.Message):
    __slots__ = ["constructor_calldata", "contract_address_salt", "class_hash"]
    CONSTRUCTOR_CALLDATA_FIELD_NUMBER: _ClassVar[int]
    CONTRACT_ADDRESS_SALT_FIELD_NUMBER: _ClassVar[int]
    CLASS_HASH_FIELD_NUMBER: _ClassVar[int]
    constructor_calldata: _containers.RepeatedCompositeFieldContainer[
        _types_pb2.FieldElement
    ]
    contract_address_salt: _types_pb2.FieldElement
    class_hash: _types_pb2.FieldElement
    def __init__(
        self,
        constructor_calldata: _Optional[
            _Iterable[_Union[_types_pb2.FieldElement, _Mapping]]
        ] = ...,
        contract_address_salt: _Optional[
            _Union[_types_pb2.FieldElement, _Mapping]
        ] = ...,
        class_hash: _Optional[_Union[_types_pb2.FieldElement, _Mapping]] = ...,
    ) -> None: ...

class DeclareTransaction(_message.Message):
    __slots__ = ["class_hash", "sender_address", "compiled_class_hash"]
    CLASS_HASH_FIELD_NUMBER: _ClassVar[int]
    SENDER_ADDRESS_FIELD_NUMBER: _ClassVar[int]
    COMPILED_CLASS_HASH_FIELD_NUMBER: _ClassVar[int]
    class_hash: _types_pb2.FieldElement
    sender_address: _types_pb2.FieldElement
    compiled_class_hash: _types_pb2.FieldElement
    def __init__(
        self,
        class_hash: _Optional[_Union[_types_pb2.FieldElement, _Mapping]] = ...,
        sender_address: _Optional[_Union[_types_pb2.FieldElement, _Mapping]] = ...,
        compiled_class_hash: _Optional[_Union[_types_pb2.FieldElement, _Mapping]] = ...,
    ) -> None: ...

class DeclareTransactionV3(_message.Message):
    __slots__ = [
        "class_hash",
        "sender_address",
        "compiled_class_hash",
        "account_deployment_data",
    ]
    CLASS_HASH_FIELD_NUMBER: _ClassVar[int]
    SENDER_ADDRESS_FIELD_NUMBER: _ClassVar[int]
    COMPILED_CLASS_HASH_FIELD_NUMBER: _ClassVar[int]
    ACCOUNT_DEPLOYMENT_DATA_FIELD_NUMBER: _ClassVar[int]
    class_hash: _types_pb2.FieldElement
    sender_address: _types_pb2.FieldElement
    compiled_class_hash: _types_pb2.FieldElement
    account_deployment_data: _containers.RepeatedCompositeFieldContainer[
        _types_pb2.FieldElement
    ]
    def __init__(
        self,
        class_hash: _Optional[_Union[_types_pb2.FieldElement, _Mapping]] = ...,
        sender_address: _Optional[_Union[_types_pb2.FieldElement, _Mapping]] = ...,
        compiled_class_hash: _Optional[_Union[_types_pb2.FieldElement, _Mapping]] = ...,
        account_deployment_data: _Optional[
            _Iterable[_Union[_types_pb2.FieldElement, _Mapping]]
        ] = ...,
    ) -> None: ...

class L1HandlerTransaction(_message.Message):
    __slots__ = ["contract_address", "entry_point_selector", "calldata"]
    CONTRACT_ADDRESS_FIELD_NUMBER: _ClassVar[int]
    ENTRY_POINT_SELECTOR_FIELD_NUMBER: _ClassVar[int]
    CALLDATA_FIELD_NUMBER: _ClassVar[int]
    contract_address: _types_pb2.FieldElement
    entry_point_selector: _types_pb2.FieldElement
    calldata: _containers.RepeatedCompositeFieldContainer[_types_pb2.FieldElement]
    def __init__(
        self,
        contract_address: _Optional[_Union[_types_pb2.FieldElement, _Mapping]] = ...,
        entry_point_selector: _Optional[
            _Union[_types_pb2.FieldElement, _Mapping]
        ] = ...,
        calldata: _Optional[_Iterable[_Union[_types_pb2.FieldElement, _Mapping]]] = ...,
    ) -> None: ...

class DeployAccountTransaction(_message.Message):
    __slots__ = ["constructor_calldata", "contract_address_salt", "class_hash"]
    CONSTRUCTOR_CALLDATA_FIELD_NUMBER: _ClassVar[int]
    CONTRACT_ADDRESS_SALT_FIELD_NUMBER: _ClassVar[int]
    CLASS_HASH_FIELD_NUMBER: _ClassVar[int]
    constructor_calldata: _containers.RepeatedCompositeFieldContainer[
        _types_pb2.FieldElement
    ]
    contract_address_salt: _types_pb2.FieldElement
    class_hash: _types_pb2.FieldElement
    def __init__(
        self,
        constructor_calldata: _Optional[
            _Iterable[_Union[_types_pb2.FieldElement, _Mapping]]
        ] = ...,
        contract_address_salt: _Optional[
            _Union[_types_pb2.FieldElement, _Mapping]
        ] = ...,
        class_hash: _Optional[_Union[_types_pb2.FieldElement, _Mapping]] = ...,
    ) -> None: ...

class DeployAccountTransactionV3(_message.Message):
    __slots__ = ["constructor_calldata", "contract_address_salt", "class_hash"]
    CONSTRUCTOR_CALLDATA_FIELD_NUMBER: _ClassVar[int]
    CONTRACT_ADDRESS_SALT_FIELD_NUMBER: _ClassVar[int]
    CLASS_HASH_FIELD_NUMBER: _ClassVar[int]
    constructor_calldata: _containers.RepeatedCompositeFieldContainer[
        _types_pb2.FieldElement
    ]
    contract_address_salt: _types_pb2.FieldElement
    class_hash: _types_pb2.FieldElement
    def __init__(
        self,
        constructor_calldata: _Optional[
            _Iterable[_Union[_types_pb2.FieldElement, _Mapping]]
        ] = ...,
        contract_address_salt: _Optional[
            _Union[_types_pb2.FieldElement, _Mapping]
        ] = ...,
        class_hash: _Optional[_Union[_types_pb2.FieldElement, _Mapping]] = ...,
    ) -> None: ...

class TransactionReceipt(_message.Message):
    __slots__ = [
        "transaction_hash",
        "transaction_index",
        "actual_fee",
        "l2_to_l1_messages",
        "events",
        "contract_address",
        "execution_status",
        "revert_reason",
        "actual_fee_paid",
        "execution_resources",
    ]
    TRANSACTION_HASH_FIELD_NUMBER: _ClassVar[int]
    TRANSACTION_INDEX_FIELD_NUMBER: _ClassVar[int]
    ACTUAL_FEE_FIELD_NUMBER: _ClassVar[int]
    L2_TO_L1_MESSAGES_FIELD_NUMBER: _ClassVar[int]
    EVENTS_FIELD_NUMBER: _ClassVar[int]
    CONTRACT_ADDRESS_FIELD_NUMBER: _ClassVar[int]
    EXECUTION_STATUS_FIELD_NUMBER: _ClassVar[int]
    REVERT_REASON_FIELD_NUMBER: _ClassVar[int]
    ACTUAL_FEE_PAID_FIELD_NUMBER: _ClassVar[int]
    EXECUTION_RESOURCES_FIELD_NUMBER: _ClassVar[int]
    transaction_hash: _types_pb2.FieldElement
    transaction_index: int
    actual_fee: _types_pb2.FieldElement
    l2_to_l1_messages: _containers.RepeatedCompositeFieldContainer[L2ToL1Message]
    events: _containers.RepeatedCompositeFieldContainer[Event]
    contract_address: _types_pb2.FieldElement
    execution_status: ExecutionStatus
    revert_reason: str
    actual_fee_paid: FeePayment
    execution_resources: ExecutionResources
    def __init__(
        self,
        transaction_hash: _Optional[_Union[_types_pb2.FieldElement, _Mapping]] = ...,
        transaction_index: _Optional[int] = ...,
        actual_fee: _Optional[_Union[_types_pb2.FieldElement, _Mapping]] = ...,
        l2_to_l1_messages: _Optional[_Iterable[_Union[L2ToL1Message, _Mapping]]] = ...,
        events: _Optional[_Iterable[_Union[Event, _Mapping]]] = ...,
        contract_address: _Optional[_Union[_types_pb2.FieldElement, _Mapping]] = ...,
        execution_status: _Optional[_Union[ExecutionStatus, str]] = ...,
        revert_reason: _Optional[str] = ...,
        actual_fee_paid: _Optional[_Union[FeePayment, _Mapping]] = ...,
        execution_resources: _Optional[_Union[ExecutionResources, _Mapping]] = ...,
    ) -> None: ...

class L2ToL1MessageWithTransaction(_message.Message):
    __slots__ = ["transaction", "receipt", "message"]
    TRANSACTION_FIELD_NUMBER: _ClassVar[int]
    RECEIPT_FIELD_NUMBER: _ClassVar[int]
    MESSAGE_FIELD_NUMBER: _ClassVar[int]
    transaction: Transaction
    receipt: TransactionReceipt
    message: L2ToL1Message
    def __init__(
        self,
        transaction: _Optional[_Union[Transaction, _Mapping]] = ...,
        receipt: _Optional[_Union[TransactionReceipt, _Mapping]] = ...,
        message: _Optional[_Union[L2ToL1Message, _Mapping]] = ...,
    ) -> None: ...

class L2ToL1Message(_message.Message):
    __slots__ = ["to_address", "payload", "index", "from_address"]
    TO_ADDRESS_FIELD_NUMBER: _ClassVar[int]
    PAYLOAD_FIELD_NUMBER: _ClassVar[int]
    INDEX_FIELD_NUMBER: _ClassVar[int]
    FROM_ADDRESS_FIELD_NUMBER: _ClassVar[int]
    to_address: _types_pb2.FieldElement
    payload: _containers.RepeatedCompositeFieldContainer[_types_pb2.FieldElement]
    index: int
    from_address: _types_pb2.FieldElement
    def __init__(
        self,
        to_address: _Optional[_Union[_types_pb2.FieldElement, _Mapping]] = ...,
        payload: _Optional[_Iterable[_Union[_types_pb2.FieldElement, _Mapping]]] = ...,
        index: _Optional[int] = ...,
        from_address: _Optional[_Union[_types_pb2.FieldElement, _Mapping]] = ...,
    ) -> None: ...

class EventWithTransaction(_message.Message):
    __slots__ = ["transaction", "receipt", "event"]
    TRANSACTION_FIELD_NUMBER: _ClassVar[int]
    RECEIPT_FIELD_NUMBER: _ClassVar[int]
    EVENT_FIELD_NUMBER: _ClassVar[int]
    transaction: Transaction
    receipt: TransactionReceipt
    event: Event
    def __init__(
        self,
        transaction: _Optional[_Union[Transaction, _Mapping]] = ...,
        receipt: _Optional[_Union[TransactionReceipt, _Mapping]] = ...,
        event: _Optional[_Union[Event, _Mapping]] = ...,
    ) -> None: ...

class Event(_message.Message):
    __slots__ = ["from_address", "keys", "data", "index"]
    FROM_ADDRESS_FIELD_NUMBER: _ClassVar[int]
    KEYS_FIELD_NUMBER: _ClassVar[int]
    DATA_FIELD_NUMBER: _ClassVar[int]
    INDEX_FIELD_NUMBER: _ClassVar[int]
    from_address: _types_pb2.FieldElement
    keys: _containers.RepeatedCompositeFieldContainer[_types_pb2.FieldElement]
    data: _containers.RepeatedCompositeFieldContainer[_types_pb2.FieldElement]
    index: int
    def __init__(
        self,
        from_address: _Optional[_Union[_types_pb2.FieldElement, _Mapping]] = ...,
        keys: _Optional[_Iterable[_Union[_types_pb2.FieldElement, _Mapping]]] = ...,
        data: _Optional[_Iterable[_Union[_types_pb2.FieldElement, _Mapping]]] = ...,
        index: _Optional[int] = ...,
    ) -> None: ...

class StateUpdate(_message.Message):
    __slots__ = ["new_root", "old_root", "state_diff"]
    NEW_ROOT_FIELD_NUMBER: _ClassVar[int]
    OLD_ROOT_FIELD_NUMBER: _ClassVar[int]
    STATE_DIFF_FIELD_NUMBER: _ClassVar[int]
    new_root: _types_pb2.FieldElement
    old_root: _types_pb2.FieldElement
    state_diff: StateDiff
    def __init__(
        self,
        new_root: _Optional[_Union[_types_pb2.FieldElement, _Mapping]] = ...,
        old_root: _Optional[_Union[_types_pb2.FieldElement, _Mapping]] = ...,
        state_diff: _Optional[_Union[StateDiff, _Mapping]] = ...,
    ) -> None: ...

class StateDiff(_message.Message):
    __slots__ = [
        "storage_diffs",
        "declared_contracts",
        "deployed_contracts",
        "nonces",
        "declared_classes",
        "replaced_classes",
    ]
    STORAGE_DIFFS_FIELD_NUMBER: _ClassVar[int]
    DECLARED_CONTRACTS_FIELD_NUMBER: _ClassVar[int]
    DEPLOYED_CONTRACTS_FIELD_NUMBER: _ClassVar[int]
    NONCES_FIELD_NUMBER: _ClassVar[int]
    DECLARED_CLASSES_FIELD_NUMBER: _ClassVar[int]
    REPLACED_CLASSES_FIELD_NUMBER: _ClassVar[int]
    storage_diffs: _containers.RepeatedCompositeFieldContainer[StorageDiff]
    declared_contracts: _containers.RepeatedCompositeFieldContainer[DeclaredContract]
    deployed_contracts: _containers.RepeatedCompositeFieldContainer[DeployedContract]
    nonces: _containers.RepeatedCompositeFieldContainer[NonceUpdate]
    declared_classes: _containers.RepeatedCompositeFieldContainer[DeclaredClass]
    replaced_classes: _containers.RepeatedCompositeFieldContainer[ReplacedClass]
    def __init__(
        self,
        storage_diffs: _Optional[_Iterable[_Union[StorageDiff, _Mapping]]] = ...,
        declared_contracts: _Optional[
            _Iterable[_Union[DeclaredContract, _Mapping]]
        ] = ...,
        deployed_contracts: _Optional[
            _Iterable[_Union[DeployedContract, _Mapping]]
        ] = ...,
        nonces: _Optional[_Iterable[_Union[NonceUpdate, _Mapping]]] = ...,
        declared_classes: _Optional[_Iterable[_Union[DeclaredClass, _Mapping]]] = ...,
        replaced_classes: _Optional[_Iterable[_Union[ReplacedClass, _Mapping]]] = ...,
    ) -> None: ...

class StorageDiff(_message.Message):
    __slots__ = ["contract_address", "storage_entries"]
    CONTRACT_ADDRESS_FIELD_NUMBER: _ClassVar[int]
    STORAGE_ENTRIES_FIELD_NUMBER: _ClassVar[int]
    contract_address: _types_pb2.FieldElement
    storage_entries: _containers.RepeatedCompositeFieldContainer[StorageEntry]
    def __init__(
        self,
        contract_address: _Optional[_Union[_types_pb2.FieldElement, _Mapping]] = ...,
        storage_entries: _Optional[_Iterable[_Union[StorageEntry, _Mapping]]] = ...,
    ) -> None: ...

class StorageEntry(_message.Message):
    __slots__ = ["key", "value"]
    KEY_FIELD_NUMBER: _ClassVar[int]
    VALUE_FIELD_NUMBER: _ClassVar[int]
    key: _types_pb2.FieldElement
    value: _types_pb2.FieldElement
    def __init__(
        self,
        key: _Optional[_Union[_types_pb2.FieldElement, _Mapping]] = ...,
        value: _Optional[_Union[_types_pb2.FieldElement, _Mapping]] = ...,
    ) -> None: ...

class DeclaredContract(_message.Message):
    __slots__ = ["class_hash"]
    CLASS_HASH_FIELD_NUMBER: _ClassVar[int]
    class_hash: _types_pb2.FieldElement
    def __init__(
        self, class_hash: _Optional[_Union[_types_pb2.FieldElement, _Mapping]] = ...
    ) -> None: ...

class DeclaredClass(_message.Message):
    __slots__ = ["class_hash", "compiled_class_hash"]
    CLASS_HASH_FIELD_NUMBER: _ClassVar[int]
    COMPILED_CLASS_HASH_FIELD_NUMBER: _ClassVar[int]
    class_hash: _types_pb2.FieldElement
    compiled_class_hash: _types_pb2.FieldElement
    def __init__(
        self,
        class_hash: _Optional[_Union[_types_pb2.FieldElement, _Mapping]] = ...,
        compiled_class_hash: _Optional[_Union[_types_pb2.FieldElement, _Mapping]] = ...,
    ) -> None: ...

class ReplacedClass(_message.Message):
    __slots__ = ["contract_address", "class_hash"]
    CONTRACT_ADDRESS_FIELD_NUMBER: _ClassVar[int]
    CLASS_HASH_FIELD_NUMBER: _ClassVar[int]
    contract_address: _types_pb2.FieldElement
    class_hash: _types_pb2.FieldElement
    def __init__(
        self,
        contract_address: _Optional[_Union[_types_pb2.FieldElement, _Mapping]] = ...,
        class_hash: _Optional[_Union[_types_pb2.FieldElement, _Mapping]] = ...,
    ) -> None: ...

class DeployedContract(_message.Message):
    __slots__ = ["contract_address", "class_hash"]
    CONTRACT_ADDRESS_FIELD_NUMBER: _ClassVar[int]
    CLASS_HASH_FIELD_NUMBER: _ClassVar[int]
    contract_address: _types_pb2.FieldElement
    class_hash: _types_pb2.FieldElement
    def __init__(
        self,
        contract_address: _Optional[_Union[_types_pb2.FieldElement, _Mapping]] = ...,
        class_hash: _Optional[_Union[_types_pb2.FieldElement, _Mapping]] = ...,
    ) -> None: ...

class NonceUpdate(_message.Message):
    __slots__ = ["contract_address", "nonce"]
    CONTRACT_ADDRESS_FIELD_NUMBER: _ClassVar[int]
    NONCE_FIELD_NUMBER: _ClassVar[int]
    contract_address: _types_pb2.FieldElement
    nonce: _types_pb2.FieldElement
    def __init__(
        self,
        contract_address: _Optional[_Union[_types_pb2.FieldElement, _Mapping]] = ...,
        nonce: _Optional[_Union[_types_pb2.FieldElement, _Mapping]] = ...,
    ) -> None: ...

class ResourcePrice(_message.Message):
    __slots__ = ["price_in_fri", "price_in_wei"]
    PRICE_IN_FRI_FIELD_NUMBER: _ClassVar[int]
    PRICE_IN_WEI_FIELD_NUMBER: _ClassVar[int]
    price_in_fri: _types_pb2.FieldElement
    price_in_wei: _types_pb2.FieldElement
    def __init__(
        self,
        price_in_fri: _Optional[_Union[_types_pb2.FieldElement, _Mapping]] = ...,
        price_in_wei: _Optional[_Union[_types_pb2.FieldElement, _Mapping]] = ...,
    ) -> None: ...

class FeePayment(_message.Message):
    __slots__ = ["amount", "unit"]
    AMOUNT_FIELD_NUMBER: _ClassVar[int]
    UNIT_FIELD_NUMBER: _ClassVar[int]
    amount: _types_pb2.FieldElement
    unit: PriceUnit
    def __init__(
        self,
        amount: _Optional[_Union[_types_pb2.FieldElement, _Mapping]] = ...,
        unit: _Optional[_Union[PriceUnit, str]] = ...,
    ) -> None: ...

class ExecutionResources(_message.Message):
    __slots__ = ["computation", "data_availability"]
    COMPUTATION_FIELD_NUMBER: _ClassVar[int]
    DATA_AVAILABILITY_FIELD_NUMBER: _ClassVar[int]
    computation: ComputationResources
    data_availability: DataAvailabilityResources
    def __init__(
        self,
        computation: _Optional[_Union[ComputationResources, _Mapping]] = ...,
        data_availability: _Optional[_Union[DataAvailabilityResources, _Mapping]] = ...,
    ) -> None: ...

class ComputationResources(_message.Message):
    __slots__ = [
        "steps",
        "memory_holes",
        "range_check_builtin_applications",
        "pedersen_builtin_applications",
        "poseidon_builtin_applications",
        "ec_op_builtin_applications",
        "ecdsa_builtin_applications",
        "bitwise_builtin_applications",
        "keccak_builtin_applications",
        "segment_arena_builtin",
    ]
    STEPS_FIELD_NUMBER: _ClassVar[int]
    MEMORY_HOLES_FIELD_NUMBER: _ClassVar[int]
    RANGE_CHECK_BUILTIN_APPLICATIONS_FIELD_NUMBER: _ClassVar[int]
    PEDERSEN_BUILTIN_APPLICATIONS_FIELD_NUMBER: _ClassVar[int]
    POSEIDON_BUILTIN_APPLICATIONS_FIELD_NUMBER: _ClassVar[int]
    EC_OP_BUILTIN_APPLICATIONS_FIELD_NUMBER: _ClassVar[int]
    ECDSA_BUILTIN_APPLICATIONS_FIELD_NUMBER: _ClassVar[int]
    BITWISE_BUILTIN_APPLICATIONS_FIELD_NUMBER: _ClassVar[int]
    KECCAK_BUILTIN_APPLICATIONS_FIELD_NUMBER: _ClassVar[int]
    SEGMENT_ARENA_BUILTIN_FIELD_NUMBER: _ClassVar[int]
    steps: int
    memory_holes: int
    range_check_builtin_applications: int
    pedersen_builtin_applications: int
    poseidon_builtin_applications: int
    ec_op_builtin_applications: int
    ecdsa_builtin_applications: int
    bitwise_builtin_applications: int
    keccak_builtin_applications: int
    segment_arena_builtin: int
    def __init__(
        self,
        steps: _Optional[int] = ...,
        memory_holes: _Optional[int] = ...,
        range_check_builtin_applications: _Optional[int] = ...,
        pedersen_builtin_applications: _Optional[int] = ...,
        poseidon_builtin_applications: _Optional[int] = ...,
        ec_op_builtin_applications: _Optional[int] = ...,
        ecdsa_builtin_applications: _Optional[int] = ...,
        bitwise_builtin_applications: _Optional[int] = ...,
        keccak_builtin_applications: _Optional[int] = ...,
        segment_arena_builtin: _Optional[int] = ...,
    ) -> None: ...

class DataAvailabilityResources(_message.Message):
    __slots__ = ["l1_gas", "l1_data_gas"]
    L1_GAS_FIELD_NUMBER: _ClassVar[int]
    L1_DATA_GAS_FIELD_NUMBER: _ClassVar[int]
    l1_gas: int
    l1_data_gas: int
    def __init__(
        self, l1_gas: _Optional[int] = ..., l1_data_gas: _Optional[int] = ...
    ) -> None: ...

class ResourceBoundsMapping(_message.Message):
    __slots__ = ["l1_gas", "l2_gas"]
    L1_GAS_FIELD_NUMBER: _ClassVar[int]
    L2_GAS_FIELD_NUMBER: _ClassVar[int]
    l1_gas: ResourceBounds
    l2_gas: ResourceBounds
    def __init__(
        self,
        l1_gas: _Optional[_Union[ResourceBounds, _Mapping]] = ...,
        l2_gas: _Optional[_Union[ResourceBounds, _Mapping]] = ...,
    ) -> None: ...

class ResourceBounds(_message.Message):
    __slots__ = ["max_amount", "max_price_per_unit"]
    MAX_AMOUNT_FIELD_NUMBER: _ClassVar[int]
    MAX_PRICE_PER_UNIT_FIELD_NUMBER: _ClassVar[int]
    max_amount: int
    max_price_per_unit: Uint128
    def __init__(
        self,
        max_amount: _Optional[int] = ...,
        max_price_per_unit: _Optional[_Union[Uint128, _Mapping]] = ...,
    ) -> None: ...

class Uint128(_message.Message):
    __slots__ = ["low", "high"]
    LOW_FIELD_NUMBER: _ClassVar[int]
    HIGH_FIELD_NUMBER: _ClassVar[int]
    low: int
    high: int
    def __init__(
        self, low: _Optional[int] = ..., high: _Optional[int] = ...
    ) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: starknet.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2

DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b"\n\x0estarknet.proto\x12\x19\x61pibara.starknet.v1alpha2\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x0btypes.proto\"\xa2\x03\n\x05\x42lock\x12\x36\n\x06status\x18\x01 \x01(\x0e\x32&.apibara.starknet.v1alpha2.BlockStatus\x12\x36\n\x06header\x18\x02 \x01(\x0b\x32&.apibara.starknet.v1alpha2.BlockHeader\x12G\n\x0ctransactions\x18\x03 \x03(\x0b\x32\x31.apibara.starknet.v1alpha2.TransactionWithReceipt\x12<\n\x0cstate_update\x18\x04 \x01(\x0b\x32&.apibara.starknet.v1alpha2.StateUpdate\x12?\n\x06\x65vents\x18\x05 \x03(\x0b\x32/.apibara.starknet.v1alpha2.EventWithTransaction\x12R\n\x11l2_to_l1_messages\x18\x06 \x03(\x0b\x32\x37.apibara.starknet.v1alpha2.L2ToL1MessageWithTransaction\x12\r\n\x05\x65mpty\x18\x07 \x01(\x08\"\xc7\x04\n\x0b\x42lockHeader\x12;\n\nblock_hash\x18\x01 \x01(\x0b\x32'.apibara.starknet.v1alpha2.FieldElement\x12\x42\n\x11parent_block_hash\x18\x02 \x01(\x0b\x32'.apibara.starknet.v1alpha2.FieldElement\x12\x14\n\x0c\x62lock_number\x18\x03 \x01(\x04\x12\x42\n\x11sequencer_address\x18\x04 \x01(\x0b\x32'.apibara.starknet.v1alpha2.FieldElement\x12\x39\n\x08new_root\x18\x05 \x01(\x0b\x32'.apibara.starknet.v1alpha2.FieldElement\x12-\n\ttimestamp\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x18\n\x10starknet_version\x18\x07 \x01(\t\x12>\n\x0cl1_gas_price\x18\x08 \x01(\x0b\x32(.apibara.starknet.v1alpha2.ResourcePrice\x12\x43\n\x11l1_data_gas_price\x18\t \x01(\x0b\x32(.apibara.starknet.v1alpha2.ResourcePrice\x12T\n\x19l1_data_availability_mode\x18\n \x01(\x0e\x32\x31.apibara.starknet.v1alpha2.L1DataAvailabilityMode\"\x95\x01\n\x16TransactionWithReceipt\x12;\n\x0btransaction\x18\x01 \x01(\x0b\x32&.apibara.starknet.v1alpha2.Transaction\x12>\n\x07receipt\x18\x02 \x01(\x0b\x32-.apibara.starknet.v1alpha2.TransactionReceipt\"\xd8\x05\n\x0bTransaction\x12\x38\n\x04meta\x18\x01 \x01(\x0b\x32*.apibara.starknet.v1alpha2.TransactionMeta\x12\x43\n\tinvoke_v0\x18\x02 \x01(\x0b\x32..apibara.starknet.v1alpha2.InvokeTransactionV0H\x00\x12\x43\n\tinvoke_v1\x18\x03 \x01(\x0b\x32..apibara.starknet.v1alpha2.InvokeTransactionV1H\x00\x12>\n\x06\x64\x65ploy\x18\x04 \x01(\x0b\x32,.apibara.starknet.v1alpha2.DeployTransactionH\x00\x12@\n\x07\x64\x65\x63lare\x18\x05 \x01(\x0b\x32-.apibara.starknet.v1alpha2.DeclareTransactionH\x00\x12\x45\n\nl1_handler\x18\x06 \x01(\x0b\x32/.apibara.starknet.v1alpha2.L1HandlerTransactionH\x00\x12M\n\x0e\x64\x65ploy_account\x18\x07 \x01(\x0b\x32\x33.apibara.starknet.v1alpha2.DeployAccountTransactionH\x00\x12R\n\x11\x64\x65ploy_account_v3\x18\x08 \x01(\x0b\x32\x35.apibara.starknet.v1alpha2.DeployAccountTransactionV3H\x00\x12\x43\n\tinvoke_v3\x18\t \x01(\x0b\x32..apibara.starknet.v1alpha2.InvokeTransactionV3H\x00\x12\x45\n\ndeclare_v3\x18\n \x01(\x0b\x32/.apibara.starknet.v1alpha2.DeclareTransactionV3H\x00\x42\r\n\x0btransaction\"\xe7\x04\n\x0fTransactionMeta\x12\x35\n\x04hash\x18\x01 \x01(\x0b\x32'.apibara.starknet.v1alpha2.FieldElement\x12\x38\n\x07max_fee\x18\x02 \x01(\x0b\x32'.apibara.starknet.v1alpha2.FieldElement\x12:\n\tsignature\x18\x03 \x03(\x0b\x32'.apibara.starknet.v1alpha2.FieldElement\x12\x36\n\x05nonce\x18\x04 \x01(\x0b\x32'.apibara.starknet.v1alpha2.FieldElement\x12\x0f\n\x07version\x18\x05 \x01(\x04\x12I\n\x0fresource_bounds\x18\x06 \x01(\x0b\x32\x30.apibara.starknet.v1alpha2.ResourceBoundsMapping\x12\x0b\n\x03tip\x18\x07 \x01(\x04\x12?\n\x0epaymaster_data\x18\x08 \x03(\x0b\x32'.apibara.starknet.v1alpha2.FieldElement\x12U\n\x1cnonce_data_availability_mode\x18\t \x01(\x0e\x32/.apibara.starknet.v1alpha2.DataAvailabilityMode\x12S\n\x1a\x66\x65\x65_data_availability_mode\x18\n \x01(\x0e\x32/.apibara.starknet.v1alpha2.DataAvailabilityMode\x12\x19\n\x11transaction_index\x18\x0b \x01(\x04\"\xda\x01\n\x13InvokeTransactionV0\x12\x41\n\x10\x63ontract_address\x18\x01 \x01(\x0b\x32'.apibara.starknet.v1alpha2.FieldElement\x12\x45\n\x14\x65ntry_point_selector\x18\x02 \x01(\x0b\x32'.apibara.starknet.v1alpha2.FieldElement\x12\x39\n\x08\x63\x61lldata\x18\x03 \x03(\x0b\x32'.apibara.starknet.v1alpha2.FieldElement\"\x91\x01\n\x13InvokeTransactionV1\x12?\n\x0esender_address\x18\x01 \x01(\x0b\x32'.apibara.starknet.v1alpha2.FieldElement\x12\x39\n\x08\x63\x61lldata\x18\x02 \x03(\x0b\x32'.apibara.starknet.v1alpha2.FieldElement\"\xdb\x01\n\x13InvokeTransactionV3\x12?\n\x0esender_address\x18\x01 \x01(\x0b\x32'.apibara.starknet.v1alpha2.FieldElement\x12\x39\n\x08\x63\x61lldata\x18\x02 \x03(\x0b\x32'.apibara.starknet.v1alpha2.FieldElement\x12H\n\x17\x61\x63\x63ount_deployment_data\x18\x03 \x03(\x0b\x32'.apibara.starknet.v1alpha2.FieldElement\"\xdf\x01\n\x11\x44\x65ployTransaction\x12\x45\n\x14\x63onstructor_calldata\x18\x02 \x03(\x0b\x32'.apibara.starknet.v1alpha2.FieldElement\x12\x46\n\x15\x63ontract_address_salt\x18\x03 \x01(\x0b\x32'.apibara.starknet.v1alpha2.FieldElement\x12;\n\nclass_hash\x18\x04 \x01(\x0b\x32'.apibara.starknet.v1alpha2.FieldElement\"\xd8\x01\n\x12\x44\x65\x63lareTransaction\x12;\n\nclass_hash\x18\x01 \x01(\x0b\x32'.apibara.starknet.v1alpha2.FieldElement\x12?\n\x0esender_address\x18\x02 \x01(\x0b\x32'.apibara.starknet.v1alpha2.FieldElement\x12\x44\n\x13\x63ompiled_class_hash\x18\x03 \x01(\x0b\x32'.apibara.starknet.v1alpha2.FieldElement\"\xa4\x02\n\x14\x44\x65\x63lareTransactionV3\x12;\n\nclass_hash\x18\x01 \x01(\x0b\x32'.apibara.starknet.v1alpha2.FieldElement\x12?\n\x0esender_address\x18\x02 \x01(\x0b\x32'.apibara.starknet.v1alpha2.FieldElement\x12\x44\n\x13\x63ompiled_class_hash\x18\x03 \x01(\x0b\x32'.apibara.starknet.v1alpha2.FieldElement\x12H\n\x17\x61\x63\x63ount_deployment_data\x18\x04 \x03(\x0b\x32'.apibara.starknet.v1alpha2.FieldElement\"\xdb\x01\n\x14L1HandlerTransaction\x12\x41\n\x10\x63ontract_address\x18\x02 \x01(\x0b\x32'.apibara.starknet.v1alpha2.FieldElement\x12\x45\n\x14\x65ntry_point_selector\x18\x03 \x01(\x0b\x32'.apibara.starknet.v1alpha2.FieldElement\x12\x39\n\x08\x63\x61lldata\x18\x04 \x03(\x0b\x32'.apibara.starknet.v1alpha2.FieldElement\"\xe6\x01\n\x18\x44\x65ployAccountTransaction\x12\x45\n\x14\x63onstructor_calldata\x18\x02 \x03(\x0b\x32'.apibara.starknet.v1alpha2.FieldElement\x12\x46\n\x15\x63ontract_address_salt\x18\x03 \x01(\x0b\x32'.apibara.starknet.v1alpha2.FieldElement\x12;\n\nclass_hash\x18\x04 \x01(\x0b\x32'.apibara.starknet.v1alpha2.FieldElement\"\xe8\x01\n\x1a\x44\x65ployAccountTransactionV3\x12\x45\n\x14\x63onstructor_calldata\x18\x01 \x03(\x0b\x32'.apibara.starknet.v1alpha2.FieldElement\x12\x46\n\x15\x63ontract_address_salt\x18\x02 \x01(\x0b\x32'.apibara.starknet.v1alpha2.FieldElement\x12;\n\nclass_hash\x18\x03 \x01(\x0b\x32'.apibara.starknet.v1alpha2.FieldElement\"\xd2\x04\n\x12TransactionReceipt\x12\x41\n\x10transaction_hash\x18\x01 \x01(\x0b\x32'.apibara.starknet.v1alpha2.FieldElement\x12\x19\n\x11transaction_index\x18\x02 \x01(\x04\x12;\n\nactual_fee\x18\x03 \x01(\x0b\x32'.apibara.starknet.v1alpha2.FieldElement\x12\x43\n\x11l2_to_l1_messages\x18\x04 \x03(\x0b\x32(.apibara.starknet.v1alpha2.L2ToL1Message\x12\x30\n\x06\x65vents\x18\x05 \x03(\x0b\x32 .apibara.starknet.v1alpha2.Event\x12\x41\n\x10\x63ontract_address\x18\x06 \x01(\x0b\x32'.apibara.starknet.v1alpha2.FieldElement\x12\x44\n\x10\x65xecution_status\x18\x07 \x01(\x0e\x32*.apibara.starknet.v1alpha2.ExecutionStatus\x12\x15\n\rrevert_reason\x18\x08 \x01(\t\x12>\n\x0f\x61\x63tual_fee_paid\x18\t \x01(\x0b\x32%.apibara.starknet.v1alpha2.FeePayment\x12J\n\x13\x65xecution_resources\x18\n \x01(\x0b\x32-.apibara.starknet.v1alpha2.ExecutionResources\"\xd6\x01\n\x1cL2ToL1MessageWithTransaction\x12;\n\x0btransaction\x18\x01 \x01(\x0b\x32&.apibara.starknet.v1alpha2.Transaction\x12>\n\x07receipt\x18\x02 \x01(\x0b\x32-.apibara.starknet.v1alpha2.TransactionReceipt\x12\x39\n\x07message\x18\x03 \x01(\x0b\x32(.apibara.starknet.v1alpha2.L2ToL1Message\"\xd4\x01\n\rL2ToL1Message\x12;\n\nto_address\x18\x03 \x01(\x0b\x32'.apibara.starknet.v1alpha2.FieldElement\x12\x38\n\x07payload\x18\x04 \x03(\x0b\x32'.apibara.starknet.v1alpha2.FieldElement\x12\r\n\x05index\x18\x05 \x01(\x04\x12=\n\x0c\x66rom_address\x18\x06 \x01(\x0b\x32'.apibara.starknet.v1alpha2.FieldElement\"\xc4\x01\n\x14\x45ventWithTransaction\x12;\n\x0btransaction\x18\x01 \x01(\x0b\x32&.apibara.starknet.v1alpha2.Transaction\x12>\n\x07receipt\x18\x02 \x01(\x0b\x32-.apibara.starknet.v1alpha2.TransactionReceipt\x12/\n\x05\x65vent\x18\x03 \x01(\x0b\x32 .apibara.starknet.v1alpha2.Event\"\xc3\x01\n\x05\x45vent\x12=\n\x0c\x66rom_address\x18\x01 \x01(\x0b\x32'.apibara.starknet.v1alpha2.FieldElement\x12\x35\n\x04keys\x18\x02 \x03(\x0b\x32'.apibara.starknet.v1alpha2.FieldElement\x12\x35\n\x04\x64\x61ta\x18\x03 \x03(\x0b\x32'.apibara.starknet.v1alpha2.FieldElement\x12\r\n\x05index\x18\x04 \x01(\x04\"\xbd\x01\n\x0bStateUpdate\x12\x39\n\x08new_root\x18\x01 \x01(\x0b\x32'.apibara.starknet.v1alpha2.FieldElement\x12\x39\n\x08old_root\x18\x02 \x01(\x0b\x32'.apibara.starknet.v1alpha2.FieldElement\x12\x38\n\nstate_diff\x18\x03 \x01(\x0b\x32$.apibara.starknet.v1alpha2.StateDiff\"\x9c\x03\n\tStateDiff\x12=\n\rstorage_diffs\x18\x01 \x03(\x0b\x32&.apibara.starknet.v1alpha2.StorageDiff\x12G\n\x12\x64\x65\x63lared_contracts\x18\x02 \x03(\x0b\x32+.apibara.starknet.v1alpha2.DeclaredContract\x12G\n\x12\x64\x65ployed_contracts\x18\x03 \x03(\x0b\x32+.apibara.starknet.v1alpha2.DeployedContract\x12\x36\n\x06nonces\x18\x04 \x03(\x0b\x32&.apibara.starknet.v1alpha2.NonceUpdate\x12\x42\n\x10\x64\x65\x63lared_classes\x18\x05 \x03(\x0b\x32(.apibara.starknet.v1alpha2.DeclaredClass\x12\x42\n\x10replaced_classes\x18\x06 \x03(\x0b\x32(.apibara.starknet.v1alpha2.ReplacedClass\"\x92\x01\n\x0bStorageDiff\x12\x41\n\x10\x63ontract_address\x18\x01 \x01(\x0b\x32'.apibara.starknet.v1alpha2.FieldElement\x12@\n\x0fstorage_entries\x18\x02 \x03(\x0b\x32'.apibara.starknet.v1alpha2.StorageEntry\"|\n\x0cStorageEntry\x12\x34\n\x03key\x18\x01 \x01(\x0b\x32'.apibara.starknet.v1alpha2.FieldElement\x12\x36\n\x05value\x18\x02 \x01(\x0b\x32'.apibara.starknet.v1alpha2.FieldElement\"O\n\x10\x44\x65\x63laredContract\x12;\n\nclass_hash\x18\x01 \x01(\x0b\x32'.apibara.starknet.v1alpha2.FieldElement\"\x92\x01\n\rDeclaredClass\x12;\n\nclass_hash\x18\x01 \x01(\x0b\x32'.apibara.starknet.v1alpha2.FieldElement\x12\x44\n\x13\x63ompiled_class_hash\x18\x02 \x01(\x0b\x32'.apibara.starknet.v1alpha2.FieldElement\"\x8f\x01\n\rReplacedClass\x12\x41\n\x10\x63ontract_address\x18\x01 \x01(\x0b\x32'.apibara.starknet.v1alpha2.FieldElement\x12;\n\nclass_hash\x18\x02 \x01(\x0b\x32'.apibara.starknet.v1alpha2.FieldElement\"\x92\x01\n\x10\x44\x65ployedContract\x12\x41\n\x10\x63ontract_address\x18\x01 \x01(\x0b\x32'.apibara.starknet.v1alpha2.FieldElement\x12;\n\nclass_hash\x18\x02 \x01(\x0b\x32'.apibara.starknet.v1alpha2.FieldElement\"\x88\x01\n\x0bNonceUpdate\x12\x41\n\x10\x63ontract_address\x18\x01 \x01(\x0b\x32'.apibara.starknet.v1alpha2.FieldElement\x12\x36\n\x05nonce\x18\x02 \x01(\x0b\x32'.apibara.starknet.v1alpha2.FieldElement\"\x8d\x01\n\rResourcePrice\x12=\n\x0cprice_in_fri\x18\x01 \x01(\x0b\x32'.apibara.starknet.v1alpha2.FieldElement\x12=\n\x0cprice_in_wei\x18\x02 \x01(\x0b\x32'.apibara.starknet.v1alpha2.FieldElement\"y\n\nFeePayment\x12\x37\n\x06\x61mount\x18\x01 \x01(\x0b\x32'.apibara.starknet.v1alpha2.FieldElement\x12\x32\n\x04unit\x18\x02 \x01(\x0e\x32$.apibara.starknet.v1alpha2.PriceUnit\"\xab\x01\n\x12\x45xecutionResources\x12\x44\n\x0b\x63omputation\x18\x01 \x01(\x0b\x32/.apibara.starknet.v1alpha2.ComputationResources\x12O\n\x11\x64\x61ta_availability\x18\x02 \x01(\x0b\x32\x34.apibara.starknet.v1alpha2.DataAvailabilityResources\"\xe5\x02\n\x14\x43omputationResources\x12\r\n\x05steps\x18\x01 \x01(\x04\x12\x14\n\x0cmemory_holes\x18\x02 \x01(\x04\x12(\n range_check_builtin_applications\x18\x03 \x01(\x04\x12%\n\x1dpedersen_builtin_applications\x18\x04 \x01(\x04\x12%\n\x1dposeidon_builtin_applications\x18\x05 \x01(\x04\x12\"\n\x1a\x65\x63_op_builtin_applications\x18\x06 \x01(\x04\x12\"\n\x1a\x65\x63\x64sa_builtin_applications\x18\x07 \x01(\x04\x12$\n\x1c\x62itwise_builtin_applications\x18\x08 \x01(\x04\x12#\n\x1bkeccak_builtin_applications\x18\t \x01(\x04\x12\x1d\n\x15segment_arena_builtin\x18\n \x01(\x04\"@\n\x19\x44\x61taAvailabilityResources\x12\x0e\n\x06l1_gas\x18\x01 \x01(\x04\x12\x13\n\x0bl1_data_gas\x18\x02 \x01(\x04\"\x8d\x01\n\x15ResourceBoundsMapping\x12\x39\n\x06l1_gas\x18\x01 \x01(\x0b\x32).apibara.starknet.v1alpha2.ResourceBounds\x12\x39\n\x06l2_gas\x18\x02 \x01(\x0b\x32).apibara.starknet.v1alpha2.ResourceBounds\"d\n\x0eResourceBounds\x12\x12\n\nmax_amount\x18\x01 \x01(\x04\x12>\n\x12max_price_per_unit\x18\x02 \x01(\x0b\x32\".apibara.starknet.v1alpha2.Uint128\"$\n\x07Uint128\x12\x0b\n\x03low\x18\x01 \x01(\x04\x12\x0c\n\x04high\x18\x02 \x01(\x04*\x8f\x01\n\x16L1DataAvailabilityMode\x12)\n%L1_DATA_AVAILABILITY_MODE_UNSPECIFIED\x10\x00\x12\"\n\x1eL1_DATA_AVAILABILITY_MODE_BLOB\x10\x01\x12&\n\"L1_DATA_AVAILABILITY_MODE_CALLDATA\x10\x02*\xa2\x01\n\x0b\x42lockStatus\x12\x1c\n\x18\x42LOCK_STATUS_UNSPECIFIED\x10\x00\x12\x18\n\x14\x42LOCK_STATUS_PENDING\x10\x01\x12\x1f\n\x1b\x42LOCK_STATUS_ACCEPTED_ON_L2\x10\x02\x12\x1f\n\x1b\x42LOCK_STATUS_ACCEPTED_ON_L1\x10\x03\x12\x19\n\x15\x42LOCK_STATUS_REJECTED\x10\x04*r\n\x0f\x45xecutionStatus\x12 \n\x1c\x45XECUTION_STATUS_UNSPECIFIED\x10\x00\x12\x1e\n\x1a\x45XECUTION_STATUS_SUCCEEDED\x10\x01\x12\x1d\n\x19\x45XECUTION_STATUS_REVERTED\x10\x02*O\n\tPriceUnit\x12\x1a\n\x16PRICE_UNIT_UNSPECIFIED\x10\x00\x12\x12\n\x0ePRICE_UNIT_WEI\x10\x01\x12\x12\n\x0ePRICE_UNIT_FRI\x10\x02*|\n\x14\x44\x61taAvailabilityMode\x12&\n\"DATA_AVAILABILITY_MODE_UNSPECIFIED\x10\x00\x12\x1d\n\x19\x44\x41TA_AVAILABILITY_MODE_L1\x10\x01\x12\x1d\n\x19\x44\x41TA_AVAILABILITY_MODE_L2\x10\x02\x62\x06proto3"
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, "starknet_pb2", _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
    DESCRIPTOR._options = None
    _globals["_L1DATAAVAILABILITYMODE"]._serialized_start = 8744
    _globals["_L1DATAAVAILABILITYMODE"]._serialized_end = 8887
    _globals["_BLOCKSTATUS"]._serialized_start = 8890
    _globals["_BLOCKSTATUS"]._serialized_end = 9052
    _globals["_EXECUTIONSTATUS"]._serialized_start = 9054
    _globals["_EXECUTIONSTATUS"]._serialized_end = 9168
    _globals["_PRICEUNIT"]._serialized_start = 9170
    _globals["_PRICEUNIT"]._serialized_end = 9249
    _globals["_DATAAVAILABILITYMODE"]._serialized_start = 9251
    _globals["_DATAAVAILABILITYMODE"]._serialized_end = 9375
    _globals["_BLOCK"]._serialized_start = 92
    _globals["_BLOCK"]._serialized_end = 510
    _globals["_BLOCKHEADER"]._serialized_start = 513
    _globals["_BLOCKHEADER"]._serialized_end = 1096
    _globals["_TRANSACTIONWITHRECEIPT"]._serialized_start = 1099
    _globals["_TRANSACTIONWITHRECEIPT"]._serialized_end = 1248
    _globals["_TRANSACTION"]._serialized_start = 1251
    _globals["_TRANSACTION"]._serialized_end = 1979
    _globals["_TRANSACTIONMETA"]._serialized_start = 1982
    _globals["_TRANSACTIONMETA"]._serialized_end = 2597
    _globals["_INVOKETRANSACTIONV0"]._serialized_start = 2600
    _globals["_INVOKETRANSACTIONV0"]._serialized_end = 2818
    _globals["_INVOKETRANSACTIONV1"]._serialized_start = 2821
    _globals["_INVOKETRANSACTIONV1"]._serialized_end = 2966
    _globals["_INVOKETRANSACTIONV3"]._serialized_start = 2969
    _globals["_INVOKETRANSACTIONV3"]._serialized_end = 3188
    _globals["_DEPLOYTRANSACTION"]._serialized_start = 3191
    _globals["_DEPLOYTRANSACTION"]._serialized_end = 3414
    _globals["_DECLARETRANSACTION"]._serialized_start = 3417
    _globals["_DECLARETRANSACTION"]._serialized_end = 3633
    _globals["_DECLARETRANSACTIONV3"]._serialized_start = 3636
    _globals["_DECLARETRANSACTIONV3"]._serialized_end = 3928
    _globals["_L1HANDLERTRANSACTION"]._serialized_start = 3931
    _globals["_L1HANDLERTRANSACTION"]._serialized_end = 4150
    _globals["_DEPLOYACCOUNTTRANSACTION"]._serialized_start = 4153
    _globals["_DEPLOYACCOUNTTRANSACTION"]._serialized_end = 4383
    _globals["_DEPLOYACCOUNTTRANSACTIONV3"]._serialized_start = 4386
    _globals["_DEPLOYACCOUNTTRANSACTIONV3"]._serialized_end = 4618
    _globals["_TRANSACTIONRECEIPT"]._serialized_start = 4621
    _globals["_TRANSACTIONRECEIPT"]._serialized_end = 5215
    _globals["_L2TOL1MESSAGEWITHTRANSACTION"]._serialized_start = 5218
    _globals["_L2TOL1MESSAGEWITHTRANSACTION"]._serialized_end = 5432
    _globals["_L2TOL1MESSAGE"]._serialized_start = 5435
    _globals["_L2TOL1MESSAGE"]._serialized_end = 5647
    _globals["_EVENTWITHTRANSACTION"]._serialized_start = 5650
    _globals["_EVENTWITHTRANSACTION"]._serialized_end = 5846
    _globals["_EVENT"]._serialized_start = 5849
    _globals["_EVENT"]._serialized_end = 6044
    _globals["_STATEUPDATE"]._serialized_start = 6047
    _globals["_STATEUPDATE"]._serialized_end = 6236
    _globals["_STATEDIFF"]._serialized_start = 6239
    _globals["_STATEDIFF"]._serialized_end = 6651
    _globals["_STORAGEDIFF"]._serialized_start = 6654
    _globals["_STORAGEDIFF"]._serialized_end = 6800
    _globals["_STORAGEENTRY"]._serialized_start = 6802
    _globals["_STORAGEENTRY"]._serialized_end = 6926
    _globals["_DECLAREDCONTRACT"]._serialized_start = 6928
    _globals["_DECLAREDCONTRACT"]._serialized_end = 7007
    _globals["_DECLAREDCLASS"]._serialized_start = 7010
    _globals["_DECLAREDCLASS"]._serialized_end = 7156
    _globals["_REPLACEDCLASS"]._serialized_start = 7159
    _globals["_REPLACEDCLASS"]._serialized_end = 7302
    _globals["_DEPLOYEDCONTRACT"]._serialized_start = 7305
    _globals["_DEPLOYEDCONTRACT"]._serialized_end = 7451
    _globals["_NONCEUPDATE"]._serialized_start = 7454
    _globals["_NONCEUPDATE"]._serialized_end = 7590
    _globals["_RESOURCEPRICE"]._serialized_start = 7593
    _globals["_RESOURCEPRICE"]._serialized_end = 7734
    _globals["_FEEPAYMENT"]._serialized_start = 7736
    _globals["_FEEPAYMENT"]._serialized_end = 7857
    _globals["_EXECUTIONRESOURCES"]._serialized_start = 7860
    _globals["_EXECUTIONRESOURCES"]._serialized_end = 8031
    _globals["_COMPUTATIONRESOURCES"]._serialized_start = 8034
    _globals["_COMPUTATIONRESOURCES"]._serialized_end = 8391
    _globals["_DATAAVAILABILITYRESOURCES"]._serialized_start = 8393
    _globals["_DATAAVAILABILITYRESOURCES"]._serialized_end = 8457
    _globals["_RESOURCEBOUNDSMAPPING"]._serialized_start = 8460
    _globals["_RESOURCEBOUNDSMAPPING"]._serialized_end = 8601
    _globals["_RESOURCEBOUNDS"]._serialized_start = 8603
    _globals["_RESOURCEBOUNDS"]._serialized_end = 8703
    _globals["_UINT128"]._serialized_start = 8705
    _globals["_UINT128"]._serialized_end = 8741
# @@protoc_insertion_point(module_scope)



from google.protobuf.internal import containers as _containers
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import (
    ClassVar as _ClassVar,
    Iterable as _Iterable,
    Mapping as _Mapping,
    Optional as _Optional,
    Union as _Union,
)

DESCRIPTOR: _descriptor.FileDescriptor

class DataFinality(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = []
    DATA_STATUS_UNKNOWN: _ClassVar[DataFinality]
    DATA_STATUS_PENDING: _ClassVar[DataFinality]
    DATA_STATUS_ACCEPTED: _ClassVar[DataFinality]
    DATA_STATUS_FINALIZED: _ClassVar[DataFinality]

DATA_STATUS_UNKNOWN: DataFinality
DATA_STATUS_PENDING: DataFinality
DATA_STATUS_ACCEPTED: DataFinality
DATA_STATUS_FINALIZED: DataFinality

class StreamDataRequest(_message.Message):
    __slots__ = ["stream_id", "batch_size", "starting_cursor", "finality", "filter"]
    STREAM_ID_FIELD_NUMBER: _ClassVar[int]
    BATCH_SIZE_FIELD_NUMBER: _ClassVar[int]
    STARTING_CURSOR_FIELD_NUMBER: _ClassVar[int]
    FINALITY_FIELD_NUMBER: _ClassVar[int]
    FILTER_FIELD_NUMBER: _ClassVar[int]
    stream_id: int
    batch_size: int
    starting_cursor: Cursor
    finality: DataFinality
    filter: bytes
    def __init__(
        self,
        stream_id: _Optional[int] = ...,
        batch_size: _Optional[int] = ...,
        starting_cursor: _Optional[_Union[Cursor, _Mapping]] = ...,
        finality: _Optional[_Union[DataFinality, str]] = ...,
        filter: _Optional[bytes] = ...,
    ) -> None: ...

class StreamDataResponse(_message.Message):
    __slots__ = ["stream_id", "invalidate", "data", "heartbeat"]
    STREAM_ID_FIELD_NUMBER: _ClassVar[int]
    INVALIDATE_FIELD_NUMBER: _ClassVar[int]
    DATA_FIELD_NUMBER: _ClassVar[int]
    HEARTBEAT_FIELD_NUMBER: _ClassVar[int]
    stream_id: int
    invalidate: Invalidate
    data: Data
    heartbeat: Heartbeat
    def __init__(
        self,
        stream_id: _Optional[int] = ...,
        invalidate: _Optional[_Union[Invalidate, _Mapping]] = ...,
        data: _Optional[_Union[Data, _Mapping]] = ...,
        heartbeat: _Optional[_Union[Heartbeat, _Mapping]] = ...,
    ) -> None: ...

class Cursor(_message.Message):
    __slots__ = ["order_key", "unique_key"]
    ORDER_KEY_FIELD_NUMBER: _ClassVar[int]
    UNIQUE_KEY_FIELD_NUMBER: _ClassVar[int]
    order_key: int
    unique_key: bytes
    def __init__(
        self, order_key: _Optional[int] = ..., unique_key: _Optional[bytes] = ...
    ) -> None: ...

class Invalidate(_message.Message):
    __slots__ = ["cursor"]
    CURSOR_FIELD_NUMBER: _ClassVar[int]
    cursor: Cursor
    def __init__(self, cursor: _Optional[_Union[Cursor, _Mapping]] = ...) -> None: ...

class Data(_message.Message):
    __slots__ = ["end_cursor", "finality", "data", "cursor"]
    END_CURSOR_FIELD_NUMBER: _ClassVar[int]
    FINALITY_FIELD_NUMBER: _ClassVar[int]
    DATA_FIELD_NUMBER: _ClassVar[int]
    CURSOR_FIELD_NUMBER: _ClassVar[int]
    end_cursor: Cursor
    finality: DataFinality
    data: _containers.RepeatedScalarFieldContainer[bytes]
    cursor: Cursor
    def __init__(
        self,
        end_cursor: _Optional[_Union[Cursor, _Mapping]] = ...,
        finality: _Optional[_Union[DataFinality, str]] = ...,
        data: _Optional[_Iterable[bytes]] = ...,
        cursor: _Optional[_Union[Cursor, _Mapping]] = ...,
    ) -> None: ...

class Heartbeat(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...
